<?php

return [
    'Names' => [
        'aa' => 'अफार',
        'ab' => 'अबखेजियन',
        'ace' => 'अचीनी',
        'ach' => 'अकोली',
        'ada' => 'अडांग्मे',
        'ady' => 'अडिघे',
        'ae' => 'अवेस्तन',
        'af' => 'अफ्रिकान्स',
        'afh' => 'अफ्रिहिली',
        'agq' => 'अघेम',
        'ain' => 'ऐनू',
        'ak' => 'अकान',
        'akk' => 'अक्केडियन',
        'ale' => 'अलेउत',
        'alt' => 'दक्षिणात्य अल्ताई',
        'am' => 'अम्हारिक',
        'an' => 'अर्गोनीज',
        'ang' => 'पुरातन इंग्रजी',
        'ann' => 'ओबोलो',
        'anp' => 'अंगिका',
        'ar' => 'अरबी',
        'arc' => 'अ‍ॅरेमाइक',
        'arn' => 'मापुची',
        'arp' => 'आरापाहो',
        'ars' => 'नजदी अरबी',
        'arw' => 'आरावाक',
        'as' => 'आसामी',
        'asa' => 'असु',
        'ast' => 'अस्तुरियन',
        'atj' => 'अटिकमेक',
        'av' => 'अ‍ॅव्हेरिक',
        'awa' => 'अवधी',
        'ay' => 'ऐमरा',
        'az' => 'अझरबैजानी',
        'ba' => 'बष्किर',
        'bal' => 'बलुची',
        'ban' => 'बालिनीज',
        'bas' => 'बसा',
        'be' => 'बेलारुशियन',
        'bej' => 'बेजा',
        'bem' => 'बेम्बा',
        'bez' => 'बेना',
        'bg' => 'बल्गेरियन',
        'bgn' => 'पश्चिमी बालोची',
        'bho' => 'भोजपुरी',
        'bi' => 'बिस्लामा',
        'bik' => 'बिकोल',
        'bin' => 'बिनी',
        'bla' => 'सिक्सिका',
        'bm' => 'बाम्बारा',
        'bn' => 'बंगाली',
        'bo' => 'तिबेटी',
        'br' => 'ब्रेतॉन',
        'bra' => 'ब्रज',
        'brx' => 'बोडो',
        'bs' => 'बोस्नियन',
        'bua' => 'बुरियात',
        'bug' => 'बगिनीस',
        'byn' => 'ब्लिन',
        'ca' => 'कातालान',
        'cad' => 'कॅड्डो',
        'car' => 'कॅरिब',
        'cay' => 'केयुगा',
        'cch' => 'अत्सम',
        'ccp' => 'चाकमा',
        'ce' => 'चेचेन',
        'ceb' => 'सिबुआनो',
        'cgg' => 'किगा',
        'ch' => 'कॅमोरो',
        'chb' => 'चिब्चा',
        'chg' => 'छागाताइ',
        'chk' => 'चूकीसे',
        'chm' => 'मारी',
        'chn' => 'चिनूक जारगॉन',
        'cho' => 'चोक्तौ',
        'chp' => 'शिपेव्यान',
        'chr' => 'चेरोकी',
        'chy' => 'शेयेन्न',
        'ckb' => 'मध्य कुर्दिश',
        'clc' => 'चिलकोटिन',
        'co' => 'कॉर्सिकन',
        'cop' => 'कॉप्टिक',
        'cr' => 'क्री',
        'crg' => 'मिचिफो',
        'crh' => 'क्राइमीन तुर्की',
        'crj' => 'दक्षिणात्य इस्ट क्री',
        'crk' => 'प्लेन्स क्री',
        'crl' => 'नॉर्दर्न ईस्ट क्री',
        'crm' => 'मूस क्री',
        'crr' => 'कॅरोलिना अल्गोंक्वियन',
        'crs' => 'सेसेल्वा क्रिओल फ्रेंच',
        'cs' => 'झेक',
        'csb' => 'काशुबियन',
        'csw' => 'स्वॅम्पी क्री',
        'cu' => 'चर्च स्लाव्हिक',
        'cv' => 'चूवाश',
        'cy' => 'वेल्श',
        'da' => 'डॅनिश',
        'dak' => 'डाकोटा',
        'dar' => 'दार्गवा',
        'dav' => 'तायता',
        'de' => 'जर्मन',
        'del' => 'डेलावेयर',
        'den' => 'स्लाव्ह',
        'dgr' => 'डोग्रिब',
        'din' => 'डिन्का',
        'dje' => 'झार्मा',
        'doi' => 'डोगरी',
        'dsb' => 'लोअर सोर्बियन',
        'dua' => 'दुआला',
        'dum' => 'मिडल डच',
        'dv' => 'दिवेही',
        'dyo' => 'जोला-फॉन्यी',
        'dyu' => 'ड्युला',
        'dz' => 'झोंगखा',
        'dzg' => 'दाझागा',
        'ebu' => 'एम्बू',
        'ee' => 'एवे',
        'efi' => 'एफिक',
        'egy' => 'प्राचीन इजिप्शियन',
        'eka' => 'एकाजुक',
        'el' => 'ग्रीक',
        'elx' => 'एलामाइट',
        'en' => 'इंग्रजी',
        'enm' => 'मिडल इंग्रजी',
        'eo' => 'एस्परान्टो',
        'es' => 'स्पॅनिश',
        'et' => 'इस्टोनियन',
        'eu' => 'बास्क',
        'ewo' => 'इवोन्डो',
        'fa' => 'फारसी',
        'fan' => 'फँग',
        'fat' => 'फन्टी',
        'ff' => 'फुलाह',
        'fi' => 'फिन्निश',
        'fil' => 'फिलिपिनो',
        'fj' => 'फिजियन',
        'fo' => 'फरोइज',
        'fon' => 'फॉन',
        'fr' => 'फ्रेंच',
        'frc' => 'केजॉन फ्रेंच',
        'frm' => 'मिडल फ्रेंच',
        'fro' => 'पुरातन फ्रेंच',
        'frr' => 'उत्तरी फ्रिशियन',
        'frs' => 'पौर्वात्य फ्रिशियन',
        'fur' => 'फ्रियुलियान',
        'fy' => 'पश्चिमी फ्रिशियन',
        'ga' => 'आयरिश',
        'gaa' => 'गा',
        'gag' => 'गागाउझ',
        'gan' => 'गॅन चिनी',
        'gay' => 'गायो',
        'gba' => 'बाया',
        'gd' => 'स्कॉटिश गेलिक',
        'gez' => 'गीझ',
        'gil' => 'जिल्बरटीज',
        'gl' => 'गॅलिशियन',
        'gmh' => 'मिडल हाय जर्मन',
        'gn' => 'गुआरनी',
        'goh' => 'पुरातन हाइ जर्मन',
        'gon' => 'गाँडी',
        'gor' => 'गोरोन्तालो',
        'got' => 'गॉथिक',
        'grb' => 'ग्रेबो',
        'grc' => 'प्राचीन ग्रीक',
        'gsw' => 'स्विस जर्मन',
        'gu' => 'गुजराती',
        'guz' => 'गसी',
        'gv' => 'मांक्स',
        'gwi' => 'ग्विच’इन',
        'ha' => 'हौसा',
        'hai' => 'हैडा',
        'hak' => 'हाक्का चिनी',
        'haw' => 'हवाईयन',
        'hax' => 'दक्षिणात्य हैडा',
        'he' => 'हिब्रू',
        'hi' => 'हिंदी',
        'hil' => 'हिलीगेनॉन',
        'hit' => 'हिट्टिते',
        'hmn' => 'माँग',
        'ho' => 'हिरी मॉटू',
        'hr' => 'क्रोएशियन',
        'hsb' => 'अप्पर सॉर्बियन',
        'hsn' => 'शियांग चिनी',
        'ht' => 'हैतीयन क्रेओल',
        'hu' => 'हंगेरियन',
        'hup' => 'हूपा',
        'hur' => 'हॉल्कमेलम',
        'hy' => 'आर्मेनियन',
        'hz' => 'हरेरो',
        'ia' => 'इंटरलिंग्वा',
        'iba' => 'इबान',
        'ibb' => 'इबिबिओ',
        'id' => 'इंडोनेशियन',
        'ie' => 'इन्टरलिंग',
        'ig' => 'ईग्बो',
        'ii' => 'सिचुआन यी',
        'ik' => 'इनूपियाक',
        'ikt' => 'वेस्टर्न कॅनेडियन इनुकिटुट',
        'ilo' => 'इलोको',
        'inh' => 'इंगुश',
        'io' => 'इडौ',
        'is' => 'आईसलँडिक',
        'it' => 'इटालियन',
        'iu' => 'इनुक्तीटुट',
        'ja' => 'जपानी',
        'jbo' => 'लोज्बान',
        'jgo' => 'गोम्बा',
        'jmc' => 'मशामे',
        'jpr' => 'जुदेओ-फारसी',
        'jrb' => 'जुदेओ-अरबी',
        'jv' => 'जावानीज',
        'ka' => 'जॉर्जियन',
        'kaa' => 'कारा-कल्पक',
        'kab' => 'कबाइल',
        'kac' => 'काचिन',
        'kaj' => 'ज्जु',
        'kam' => 'काम्बा',
        'kaw' => 'कावी',
        'kbd' => 'कबार्डियन',
        'kcg' => 'त्याप',
        'kde' => 'माकोन्दे',
        'kea' => 'काबवर्दियानु',
        'kfo' => 'कोरो',
        'kg' => 'काँगो',
        'kgp' => 'काइंगांग',
        'kha' => 'खासी',
        'kho' => 'खोतानीस',
        'khq' => 'कोयरा चीनी',
        'ki' => 'किकुयू',
        'kj' => 'क्वान्यामा',
        'kk' => 'कझाक',
        'kkj' => 'काको',
        'kl' => 'कलाल्लिसत',
        'kln' => 'कालेंजीन',
        'km' => 'ख्मेर',
        'kmb' => 'किम्बन्दु',
        'kn' => 'कन्नड',
        'ko' => 'कोरियन',
        'koi' => 'कोमी-परम्याक',
        'kok' => 'कोंकणी',
        'kos' => 'कोसरियन',
        'kpe' => 'क्पेल्ले',
        'kr' => 'कनुरी',
        'krc' => 'कराचय-बाल्कर',
        'krl' => 'करेलियन',
        'kru' => 'कुरूख',
        'ks' => 'काश्मीरी',
        'ksb' => 'शांबाला',
        'ksf' => 'बाफिया',
        'ksh' => 'कोलोग्नियन',
        'ku' => 'कुर्दिश',
        'kum' => 'कुमीक',
        'kut' => 'कुतेनाई',
        'kv' => 'कोमी',
        'kw' => 'कोर्निश',
        'kwk' => 'क्वक्क्वाला',
        'ky' => 'किरगीझ',
        'la' => 'लॅटिन',
        'lad' => 'लादीनो',
        'lag' => 'लांगी',
        'lah' => 'लाह्न्डा',
        'lam' => 'लाम्बा',
        'lb' => 'लक्झेंबर्गिश',
        'lez' => 'लेझ्घीयन',
        'lg' => 'गांडा',
        'li' => 'लिंबूर्गिश',
        'lil' => 'लिलूएट',
        'lkt' => 'लाकोटा',
        'ln' => 'लिंगाला',
        'lo' => 'लाओ',
        'lol' => 'मोंगो',
        'lou' => 'ल्युसियाना क्रिओल',
        'loz' => 'लोझि',
        'lrc' => 'उत्तरी ल्युरी',
        'lsm' => 'सामिया',
        'lt' => 'लिथुआनियन',
        'lu' => 'ल्यूबा-कटांगा',
        'lua' => 'लुबा-लुलुआ',
        'lui' => 'लुइसेनो',
        'lun' => 'लुन्डा',
        'luo' => 'ल्युओ',
        'lus' => 'मिझो',
        'luy' => 'ल्युइया',
        'lv' => 'लात्व्हियन',
        'mad' => 'मादुरीस',
        'mag' => 'मगही',
        'mai' => 'मैथिली',
        'mak' => 'मकस्सर',
        'man' => 'मन्डिन्गो',
        'mas' => 'मसाई',
        'mdf' => 'मोक्ष',
        'mdr' => 'मंडार',
        'men' => 'मेन्डे',
        'mer' => 'मेरू',
        'mfe' => 'मोरिस्येन',
        'mg' => 'मलागसी',
        'mga' => 'मिडल आयरिश',
        'mgh' => 'माखुव्हा-मीट्टो',
        'mgo' => 'मीटा',
        'mh' => 'मार्शलीज',
        'mi' => 'माओरी',
        'mic' => 'मिकमॅक',
        'min' => 'मिनांग्काबाउ',
        'mk' => 'मॅसेडोनियन',
        'ml' => 'मल्याळम',
        'mn' => 'मंगोलियन',
        'mnc' => 'मान्चु',
        'mni' => 'मणिपुरी',
        'moe' => 'इन्नू-ॲमन',
        'moh' => 'मोहॉक',
        'mos' => 'मोस्सी',
        'mr' => 'मराठी',
        'ms' => 'मलय',
        'mt' => 'माल्टिज्',
        'mua' => 'मुंडांग',
        'mus' => 'क्रीक',
        'mwl' => 'मिरांडिज्',
        'mwr' => 'मारवाडी',
        'my' => 'बर्मी',
        'myv' => 'एर्झ्या',
        'mzn' => 'माझानदेरानी',
        'na' => 'नउरू',
        'nan' => 'मिन नान चिनी',
        'nap' => 'नेपोलिटान',
        'naq' => 'नामा',
        'nb' => 'नॉर्वेजियन बोकमाल',
        'nd' => 'उत्तर देबेली',
        'nds' => 'लो जर्मन',
        'ne' => 'नेपाळी',
        'new' => 'नेवारी',
        'ng' => 'डोंगा',
        'nia' => 'नियास',
        'niu' => 'नियुआन',
        'nl' => 'डच',
        'nmg' => 'क्वासिओ',
        'nn' => 'नॉर्वेजियन न्योर्स्क',
        'nnh' => 'जिएम्बून',
        'no' => 'नोर्वेजियन',
        'nog' => 'नोगाई',
        'non' => 'पुरातन नॉर्स',
        'nqo' => 'एन्को',
        'nr' => 'दक्षिणात्य देबेली',
        'nso' => 'उत्तरी सोथो',
        'nus' => 'नुएर',
        'nv' => 'नावाजो',
        'nwc' => 'अभिजात नेवारी',
        'ny' => 'न्यान्जा',
        'nym' => 'न्यामवेझी',
        'nyn' => 'न्यानकोल',
        'nyo' => 'न्योरो',
        'nzi' => 'न्झिमा',
        'oc' => 'ऑक्सितान',
        'oj' => 'ओजिब्वा',
        'ojb' => 'नॉर्थवेस्टर्न ओजिब्वा',
        'ojc' => 'सेंट्रल ओजिब्वा',
        'ojs' => 'ओजी-क्री',
        'ojw' => 'वेस्टर्न ओजिबवा',
        'oka' => 'ओकनागन',
        'om' => 'ओरोमो',
        'or' => 'उडिया',
        'os' => 'ओस्सेटिक',
        'osa' => 'ओसेज',
        'ota' => 'ओटोमान तुर्किश',
        'pa' => 'पंजाबी',
        'pag' => 'पंगासीनान',
        'pal' => 'पहलवी',
        'pam' => 'पाम्पान्गा',
        'pap' => 'पापियामेन्टो',
        'pau' => 'पालाउआन',
        'pcm' => 'नायजिरिअन पिजिन',
        'peo' => 'पुरातन फारसी',
        'phn' => 'फोनिशियन',
        'pi' => 'पाली',
        'pis' => 'पिजिन',
        'pl' => 'पोलिश',
        'pon' => 'पोह्नपियन',
        'pqm' => 'मालीसेट-पासामाक्वाड्डी',
        'prg' => 'प्रुशियन',
        'pro' => 'पुरातन प्रोव्हेन्सल',
        'ps' => 'पश्तो',
        'pt' => 'पोर्तुगीज',
        'qu' => 'क्वेचुआ',
        'quc' => 'कीशेइ',
        'raj' => 'राजस्थानी',
        'rap' => 'रापानुई',
        'rar' => 'रारोटोंगन',
        'rhg' => 'रोहिंग्या',
        'rm' => 'रोमान्श',
        'rn' => 'रुन्दी',
        'ro' => 'रोमानियन',
        'rof' => 'रोम्बो',
        'rom' => 'रोमानी',
        'ru' => 'रशियन',
        'rup' => 'अरोमानियन',
        'rw' => 'किन्यार्वान्डा',
        'rwk' => 'रव्हा',
        'sa' => 'संस्कृत',
        'sad' => 'सँडवे',
        'sah' => 'साखा',
        'sam' => 'सामरिटान अरॅमिक',
        'saq' => 'सांबुरू',
        'sas' => 'सासाक',
        'sat' => 'संताली',
        'sba' => 'गाम्बे',
        'sbp' => 'सांगु',
        'sc' => 'सर्दिनियन',
        'scn' => 'सिसिलियन',
        'sco' => 'स्कॉट्स',
        'sd' => 'सिंधी',
        'sdh' => 'दक्षिणी कुर्दिश',
        'se' => 'उत्तरी सामी',
        'seh' => 'सेना',
        'sel' => 'सेल्कप',
        'ses' => 'कोयराबोरो सेन्नी',
        'sg' => 'सांगो',
        'sga' => 'पुरातन आयरिश',
        'sh' => 'सर्बो-क्रोएशियन',
        'shi' => 'ताशेल्हिट',
        'shn' => 'शॅन',
        'si' => 'सिंहला',
        'sid' => 'सिदामो',
        'sk' => 'स्लोव्हाक',
        'sl' => 'स्लोव्हेनियन',
        'slh' => 'दक्षिणात्य लुशूटसीड',
        'sm' => 'सामोअन',
        'sma' => 'दक्षिणात्य सामी',
        'smj' => 'ल्युल सामी',
        'smn' => 'इनारी सामी',
        'sms' => 'स्कोल्ट सामी',
        'sn' => 'शोना',
        'snk' => 'सोनिन्के',
        'so' => 'सोमाली',
        'sog' => 'सोग्डिएन',
        'sq' => 'अल्बानियन',
        'sr' => 'सर्बियन',
        'srn' => 'स्रानान टॉन्गो',
        'srr' => 'सेरेर',
        'ss' => 'स्वाती',
        'ssy' => 'साहो',
        'st' => 'दक्षिणी सोथो',
        'str' => 'स्ट्राइट्स सालीश',
        'su' => 'सुंदानीज',
        'suk' => 'सुकुमा',
        'sus' => 'सुसु',
        'sux' => 'सुमेरियन',
        'sv' => 'स्वीडिश',
        'sw' => 'स्वाहिली',
        'swb' => 'कोमोरियन',
        'syc' => 'अभिजात सिरियाक',
        'syr' => 'सिरियाक',
        'ta' => 'तामिळ',
        'tce' => 'दक्षिणात्य टचोन',
        'te' => 'तेलगू',
        'tem' => 'टिम्ने',
        'teo' => 'तेसो',
        'ter' => 'तेरेनो',
        'tet' => 'तेतुम',
        'tg' => 'ताजिक',
        'tgx' => 'टॅगिश',
        'th' => 'थाई',
        'tht' => 'तहल्टन',
        'ti' => 'तिग्रिन्या',
        'tig' => 'टाइग्रे',
        'tiv' => 'तिव',
        'tk' => 'तुर्कमेन',
        'tkl' => 'टोकेलाऊ',
        'tl' => 'टागालोग',
        'tlh' => 'क्लिंगोन',
        'tli' => 'लिंगित',
        'tmh' => 'तामाशेक',
        'tn' => 'त्स्वाना',
        'to' => 'टोंगन',
        'tog' => 'न्यासा टोन्गा',
        'tok' => 'टोकि पोना',
        'tpi' => 'टोक पिसिन',
        'tr' => 'तुर्की',
        'trv' => 'तारोको',
        'ts' => 'सोंगा',
        'tsi' => 'सिम्शियन',
        'tt' => 'तातर',
        'ttm' => 'नॉर्दर्न टचोन',
        'tum' => 'तुम्बुका',
        'tvl' => 'टुवालु',
        'tw' => 'ट्वी',
        'twq' => 'तासाव्हाक',
        'ty' => 'ताहितीयन',
        'tyv' => 'टुवीनियन',
        'tzm' => 'मध्य अ‍ॅटलास तॅमाझाइट',
        'udm' => 'उदमुर्त',
        'ug' => 'उइगुर',
        'uga' => 'युगॅरिटिक',
        'uk' => 'युक्रेनियन',
        'umb' => 'उम्बुन्डु',
        'ur' => 'उर्दू',
        'uz' => 'उझ्बेक',
        'vai' => 'वाई',
        've' => 'व्हेंदा',
        'vi' => 'व्हिएतनामी',
        'vo' => 'ओलापुक',
        'vot' => 'वॉटिक',
        'vun' => 'वुंजो',
        'wa' => 'वालून',
        'wae' => 'वालसेर',
        'wal' => 'वोलायता',
        'war' => 'वारे',
        'was' => 'वाशो',
        'wbp' => 'वार्लपिरी',
        'wo' => 'वोलोफ',
        'wuu' => 'व्हू चिनी',
        'xal' => 'काल्मिक',
        'xh' => 'खोसा',
        'xog' => 'सोगा',
        'yao' => 'याओ',
        'yap' => 'यापीस',
        'yav' => 'यांगबेन',
        'ybb' => 'येमबा',
        'yi' => 'यिद्दिश',
        'yo' => 'योरुबा',
        'yrl' => 'न्हेंगाटू',
        'yue' => 'कँटोनीज',
        'za' => 'झुआंग',
        'zap' => 'झेपोटेक',
        'zbl' => 'ब्लिसिम्बॉल्स',
        'zen' => 'झेनान्गा',
        'zgh' => 'प्रमाण मोरोक्कन तॅमॅझायट',
        'zh' => 'चीनी',
        'zu' => 'झुलू',
        'zun' => 'झुनी',
        'zza' => 'झाझा',
    ],
    'LocalizedNames' => [
        'ar_001' => 'आधुनिक प्रमाणित अरबी',
        'de_AT' => 'ऑस्ट्रियन जर्मन',
        'de_CH' => 'स्विस हाय जर्मन',
        'en_AU' => 'ऑस्ट्रेलियन इंग्रजी',
        'en_CA' => 'कॅनडियन इंग्रजी',
        'en_GB' => 'ब्रिटिश इंग्रजी',
        'en_US' => 'अमेरिकन इंग्रजी',
        'es_419' => 'लॅटिन अमेरिकन स्पॅनिश',
        'es_ES' => 'युरोपियन स्पॅनिश',
        'es_MX' => 'मेक्सिकन स्पॅनिश',
        'fa_AF' => 'दारी',
        'fr_CA' => 'कॅनडियन फ्रेंच',
        'fr_CH' => 'स्विस फ्रेंच',
        'nds_NL' => 'लो सॅक्सन',
        'nl_BE' => 'फ्लेमिश',
        'pt_BR' => 'ब्राझिलियन पोर्तुगीज',
        'pt_PT' => 'युरोपियन पोर्तुगीज',
        'ro_MD' => 'मोल्डाव्हियन',
        'sw_CD' => 'काँगो स्वाहिली',
        'zh_Hans' => 'सरलीकृत चीनी',
        'zh_Hant' => 'पारंपारिक चीनी',
    ],
];
